@@ -3,7 +3,7 @@
 
 class CircuitMap(dict):
     """
-    Dictionary Of EBUS Circuit Names To Human-readable Names.
+    Mapping of EBUS-circuit names To human-readable Names.
 
     >>> c = CircuitMap({
     ...     'broadcast': '*',
@@ -26,20 +26,34 @@ class CircuitMap(dict):
     >>> c['bai'] = 'Heater'
     >>> c['boo'] = 'My Boo'
     >>> c['mc.4'] = 'Mixer Unit 2'
-    >>> c.get_humanname('bai')
-    'Heater'
-    >>> c.get_humanname('bai.3')
-    'Heater#3'
-    >>> c.get_humanname('mc.4')
-    'Mixer Unit 2'
-    >>> c.get_humanname('unknown')
-    'unknown'
-    >>> c.get_humanname('unknown.4')
-    'unknown.4'
     """
 
     def get_humanname(self, circuitname):
-        """Return human-readable name for `circuitname`."""
+        """
+        Return human-readable name for `circuitname`.
+
+        The `.X` suffix distinguishes multiple instances of the same unit, this is handled gracefully.
+
+        Returns:
+            str: human-readable name
+
+        >>> c = CircuitMap({
+        ...     'broadcast': '*',
+        ...     'bai': 'Heater',
+        ...     'mc': 'Mixer',
+        ...     'hwc': 'Water',
+        ... })
+        >>> c.get_humanname('bai')
+        'Heater'
+        >>> c.get_humanname('bai.3')
+        'Heater#3'
+        >>> c.get_humanname('mc.4')
+        'Mixer#4'
+        >>> c.get_humanname('unknown')
+        'unknown'
+        >>> c.get_humanname('unknown.4')
+        'unknown.4'
+        """
         # lookup full name
         humanname = self.get(circuitname, None)
         # loopup basename
