@@ -43,7 +43,7 @@ def add_patterns_arg(parser, opt=False):
 
 def disable_stdout_buffering():
     """Disable STDOUT buffering."""
-    sys.stdout = pyebus.util.UnbufferedStream(sys.stdout)
+    sys.stdout = UnbufferedStream(sys.stdout)
 
 
 def create_ebus(args):
@@ -82,3 +82,24 @@ def print_msg(msg, skipbroken=False):
             print(f"{field.ident:<40s} {field.fielddef.msgdef.access} {unitvalue!s:<20s}{details}")
     elif not skipbroken:
         _LOGGER.error(f"{msg.msgdef.ident}: {msg.error}")
+
+
+class UnbufferedStream:
+
+    """Unbuffered `stream`."""
+
+    def __init__(self, stream):
+        self.stream = stream
+
+    def write(self, *args, **kwargs):
+        """Write."""
+        self.stream.write(*args, **kwargs)
+        self.stream.flush()
+
+    def writelines(self, *args, **kwargs):
+        """Write multiple lines."""
+        self.stream.writelines(*args, **kwargs)
+        self.stream.flush()
+
+    def __getattr__(self, attr):
+        return getattr(self.stream, attr)
