@@ -23,7 +23,7 @@ async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
     await async_load_msgdefs(ebus, args)
-    msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"), filter_=lambda msgdef: msgdef.read or msgdef.update)
+    msgdefs = ebus.msgdefs.resolve(args.patterns, filter_=lambda msgdef: msgdef.read or msgdef.update)
     if args.defaultprio:
         msgdefs.set_defaultprio(args.defaultprio)
     print(f"Reading to {msgdefs.summary()}")
