@@ -1,4 +1,5 @@
 """Constants."""
+from datetime import timedelta
 
 
 class _NotAvailable:
@@ -21,3 +22,4 @@ DEFAULT_PORT = 8888
 DEFAULT_TIMEOUT = 10
 DEFAULT_SCANINTERVAL = 10
 DEFAULT_SCANS = 3
+DEFAULT_PRIOTHRESHOLDS = [timedelta(hours=1), timedelta(hours=4), timedelta(days=1)]
